aboutsummaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorAlon Zakai <alonzakai@gmail.com>2014-02-04 13:34:40 -0500
committerAlon Zakai <alonzakai@gmail.com>2014-02-04 13:34:40 -0500
commita1197600874aa38d7d3afa4a435830e659818f26 (patch)
tree32b85a11460dcadab69539194f4ae981d77277fe /lib
parent9ed897e34410d1e2d454c6fe819fb46827477030 (diff)
wip to remove casts on math calls
Diffstat (limited to 'lib')
-rw-r--r--lib/Target/JSBackend/CallHandlers.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/Target/JSBackend/CallHandlers.h b/lib/Target/JSBackend/CallHandlers.h
index a78d3ffbe1..b3d4799fa0 100644
--- a/lib/Target/JSBackend/CallHandlers.h
+++ b/lib/Target/JSBackend/CallHandlers.h
@@ -80,8 +80,8 @@ DEF_CALL_HANDLER(__default__, {
}
if (NumArgs > 0) text += ",";
}
- // this is an ffi call if we need casts, and it is not a Math_ builtin
- bool FFI = NeedCasts; // XXX FIXME && Name.find("Math_") != 0;
+ // this is an ffi call if we need casts, and it is not a Math_ builtin (with just 1 arg - Math with more args is different XXX)
+ bool FFI = NeedCasts; // && (NumArgs > 1 || Name.find("Math_") != 0);
unsigned FFI_OUT = FFI ? ASM_FFI_OUT : 0;
for (int i = 0; i < NumArgs; i++) {
if (!NeedCasts) {